@@ -162,13 +162,13 @@ class LinuxProtocolHandler:
         
         if rediacc_exe:
             # Use the rediacc executable directly
-            exec_command = f"{rediacc_exe} protocol-handler %u"
+            exec_command = f"{rediacc_exe} protocol run %u"
         else:
             # Fallback to Python + script method (original behavior)
             logger.warning("Could not locate rediacc executable, falling back to Python script method")
             python_exe = self.get_python_executable()
             cli_script = self.get_cli_script_path()
-            exec_command = f'{python_exe} "{cli_script}" protocol-handler %u'
+            exec_command = f'{python_exe} "{cli_script}" protocol run %u'
         
         return f"""[Desktop Entry]
 Name=Rediacc Protocol Handler
@@ -285,9 +285,11 @@ Categories=Network;
             
             # Update MIME database (if needed)
             try:
-                subprocess.run([
-                    "update-mime-database", str(mime_dir / "packages")
-                ], check=True, timeout=30)
+                mime_packages_dir = mime_dir / "packages"
+                if mime_packages_dir.exists():
+                    subprocess.run([
+                        "update-mime-database", str(mime_packages_dir)
+                    ], check=True, timeout=30, capture_output=True)
             except (subprocess.CalledProcessError, FileNotFoundError):
                 # Not critical if this fails
                 pass
@@ -326,13 +328,17 @@ Categories=Network;
             if desktop_file.exists():
                 desktop_file.unlink()
             
-            # Unregister MIME type (set to no default)
+            # Unregister MIME type by removing the association
             try:
-                subprocess.run([
-                    "xdg-mime", "default", "", self.MIME_TYPE
-                ], timeout=30)
-            except subprocess.CalledProcessError:
-                # This might fail if no default was set, which is okay
+                # Remove the mimeapps.list entry
+                mimeapps_file = Path.home() / ".config" / "mimeapps.list"
+                if mimeapps_file.exists():
+                    content = mimeapps_file.read_text()
+                    lines = [line for line in content.split('\n')
+                            if self.MIME_TYPE not in line or self.DESKTOP_ENTRY_ID not in line]
+                    mimeapps_file.write_text('\n'.join(lines))
+            except Exception:
+                # This might fail, which is okay
                 pass
             
             # Update desktop database
